How should I view global and local work sizes
I've been using OpenCL for a little while now for hobby purposes. I was wondering if someone could explain how i should view global and local work spaces. I've been playing around with it for a bit but...
View ArticleOpenCL CodeBuilder Eclipse plugin missing
Hi folks,To install the Opencl CodeBuilder Eclipse plug-in, I read the following instruction in different Intel documents: Copy the plug-in *.jar > file from...
View ArticleHow global and local work sizes are distributed in this function?
This is from a sample program for OpenCL programming. I am confused about how global and local work size are computed. They are computed based on the image size.Image size is 1920 x 1080 (w x h).What I...
View ArticleCouldn't create a context, clCreateContextFromType() returned...
My OS: ubuntu 18.04.1My CPU: Intel(R) Xeon(R) CPU E5-2609 v4 @ 1.70GHzThe information of clinfoNumber of platforms 2 Platform Name...
View ArticleCouldn't create a context, clCreateContextFromType() returned...
My OS: ubuntu 18.04.1My CPU: Intel(R) Xeon(R) CPU E5-2609 v4 @ 1.70GHzThe information of clinfo Number of platforms 2 Platform Name...
View ArticleOpenCL Code Builder can't be found in intel system studio linux
I installed the "Intel System Studio 2020" with opencl tools in ubuntu 18.04, and I can not found the opencl code builder tools in eclipse.The same thing is happened in centos 7 and centos 8.by the way...
View ArticleOpenCL Code Builder can't be found in intel system studio linux
I installed the "Intel System Studio 2020" with opencl tools in ubuntu 18.04, and I can not found the opencl code builder tools in eclipse.The same thing is happened in centos 7 and centos 8.by the way...
View ArticleCannot download the SDK
When I'm trying to download the SDK, I'm getting the "HTTP Error 503. The service is unavailable." error. Why is the download not available and when will it be? Thanks in advance!
View Articleintra mode penalty of device vme
Hi,( I have read documents as below but can not find answer about my questions:https://software.intel.com/sites/default/files/managed/43/c1/cl_intel_de... and...
View ArticleDeep learning on NI FPGA
Hello,I am new to Intel development environments.In my project, I aim to download a deep learning inference solution to a Kintex-7 FPGA on NI CompactRIO-9040I wanted to know whether it is possible to...
View Articlehandling "SISD kernels"
What is the difference in the drivers point of view of these two kernels?kernel void clmain(global const unsigned int* in, global unsigned int* out) { unsigned int id = get_global_id(0); if(id == 0) {...
View ArticleError when running aocl install
Below is the terminal command and all output for running aocl install on s10_ref supplied with the FPGA SDK for OpenCL for Ubuntu. Some of the install works, then it crashes for the reasons given...
View Articlehandling "SISD kernels"
What is the difference in the drivers point of view of these two kernels?kernel void clmain(global const unsigned int* in, global unsigned int* out) { unsigned int id = get_global_id(0); if(id == 0) {...
View ArticleOpenCL installation for Ubuntu18.04
My OS is Ubuntu 18.04.4 LTS.CPU is Intel® Xeon(R) Silver 4215 CPU @ 2.50GHz × 16 .I have two NVIDIA GPUs .0000:17:00.0 VGA compatible controller: NVIDIA Corporation TU102 [TITAN RTX] (rev...
View ArticleERROR: Unable to find Intel(R) FPGA OpenCL platform.
Hi,I'm trying to use Intel FPGA SDK for OpenCL version 20.1 and targeting Arria 10 GX board.I installed the FPGA board using aocl install, and aocl diagnose test passes, and it's able to find Intel...
View ArticleError Installing DE10 Standard to OpenCL platform
Hi folks,I bought a DE10-Standard board for an OpenCL project.In Terasic manual is written that I should copy the BSP(Board Support Package) in board folder of Intel FPGA SDK for OpenCL.So, I copied it...
View ArticleWrong links on Intel page for downloading legacy runtimes
Hi all,I don't know where to report this issue, so I'll do that here.There's a problem on this page: https://software.intel.com/en-us/articles/legacy-opencl-driversWhen one tries to get an old OpenCL...
View ArticleHave New i9-10940x and GPUPI 3.2/3.3 crashes with Intel's Opencl Driver 18.1
The title says it ALL.Additional Information : I have a EVGA x299 Motherboard, a i9-10940x, 4x8GB DDR4-4133, and have run different Nvidia/ATI/AMD video cards. I'm using Windows 7 as my Benching OS. I...
View Articleno Qt platform plugin?!?
Hi everybody, Can someone please help me with this issue, everytime i try to instal OPencl with the official installer for visual studio. everytime the process of installation ends i got " the...
View ArticleInstallation: Registration failed for unknown reason
I'm posting this because I haven't actually found a solution in the archived forum posts.The Intel® SDK for OpenCL™ Applications for Windows* is in my Products list and I have a serial number displayed...
View Article